@@ -60,15 +60,14 @@ class API(object):
         refresh_token = False
         # check if an Authorization header was set in the global token
         if self.global_session.headers.get('Authorization'):
-            # check when it was set to expire which is set in '%H:%M:%S'
+            # check when it was set to expire which is set in '%Y:%m:%d %H:%M:%S %z'
             auth_expires_in = self.global_session.headers.get(
                 'auth_expires_in')
-            # convert the string '%H:%M:%S' to time
+            # convert the string '%Y:%m:%d %H:%M:%S %z' to time
             auth_expires_in = datetime.strptime(
-                auth_expires_in, '%H:%M:%S').time()
-            # get the current time and add ten minutes to it, so that we refresh the token 10 minutes before its expiry
-            current_time = (datetime.now(timezone.utc) +
-                            timedelta(minutes=5)).time()
+                auth_expires_in, '%Y:%m:%d %H:%M:%S %z')
+            # get the current time and add ten minutes to it, so that we refresh the token 5 minutes before its expiry
+            current_time = datetime.now(timezone.utc) + timedelta(minutes=5)
             # if current time plus 5 minutes is more than when the auth needs to expire
             # refresh the token
             if current_time > auth_expires_in:
@@ -96,7 +95,7 @@ class API(object):
                 if self._identity_token.status_code == 200:
                     self.global_session.headers.update({
                         'Authorization': f"{self._identity_token.json().get('access_token',None)}",
-                        'auth_expires_in': (datetime.now(timezone.utc) + timedelta(seconds=self._identity_token.json().get('expires_in', 0))).strftime("%H:%M:%S")
+                        'auth_expires_in': (datetime.now(timezone.utc) + timedelta(seconds=self._identity_token.json().get('expires_in', 0))).strftime("%Y:%m:%d %H:%M:%S %z")
                     })
                     print("Log In Successful")
                 else:
