@@ -19,8 +19,8 @@ class Operations(object):
     FAULU = SAFCOM + 1
     CONSOLIDATED = FAULU + 1
     STANBIC = CONSOLIDATED + 1
-    FAMILY=STANBIC + 1
-    NCBA_LOOP=FAMILY + 1
+    FAMILY = STANBIC + 1
+    NCBA_LOOP = FAMILY + 1
 
     # These are the operations to be performed in Banking Identity
     # Each with a unique incremental ID
@@ -62,6 +62,23 @@ class Operations(object):
     AUTH_GET_TOKEN = JOBS_ACCOUNT_STATEMENT + 1
     AUTH_AUTHORIZE = AUTH_GET_TOKEN + 1
 
+    # Equity Bank Payment Modes
+    POLARIS_CHANNEL = AUTH_AUTHORIZE + 1
+    MISYS = POLARIS_CHANNEL + 1
+
+    BANK_PAYMENT_MODES = {
+        IFT: 'IFT',
+        MOBILE_WALLET: 'MOBILE_WALLET',
+        PESALINK_TO_BANK: 'PESALINK_TO_BANK',
+        PESALINK_TO_MOBILE: 'PESALINK_TO_MOBILE',
+        RTGS: 'RTGS',
+        SWIFT: 'SWIFT',
+        EFT: 'EFT',
+        OMN: 'OMN',
+        POLARIS_CHANNEL: 'POLARIS_CHANNEL',
+        MISYS: 'MISYS'
+    }
+
     # All end points are placed in the BANKS_CONF
     # This is to allow easy standardization of the base url, endpoint and operations
     # When calling the APIs, in this case this is done in the resource class read function
@@ -310,7 +327,7 @@ class Operations(object):
                 "operations": {
                     BALANCE:  ("get_balance", "POST"),
                     ACCOUNT_TRANSACTIONS: ("get_transactions", "POST")
-                }                
+                }
             },
             "payment": {
                 "endpoint": f"api/v1/Dapi",
@@ -326,7 +343,7 @@ class Operations(object):
                 "operations": {
                     BALANCE:  ("get_balance", "POST"),
                     ACCOUNT_TRANSACTIONS: ("get_transactions", "POST")
-                }                
+                }
             },
             "payment": {
                 "endpoint": f"api/v1/Mono",
@@ -342,7 +359,7 @@ class Operations(object):
                 "operations": {
                     BALANCE:  ("get_balance", "POST"),
                     ACCOUNT_TRANSACTIONS: ("get_transactions", "POST")
-                }                
+                }
             },
             "payment": {
                 "endpoint": f"api/v1/Plaid",
@@ -358,7 +375,7 @@ class Operations(object):
                 "operations": {
                     BALANCE:  ("get_balance", "POST"),
                     ACCOUNT_TRANSACTIONS: ("get_transactions", "POST")
-                }                
+                }
             },
             "payment": {
                 "endpoint": f"api/v1/Stitch",
