@@ -10,6 +10,7 @@ import time
 import threading
 from django.core.exceptions import ObjectDoesNotExist
 from bank_sync.Resources.helpers import IsDjangoAppClass
+from datetime import datetime
 
 _is_django_app = False
 try:
@@ -413,7 +414,7 @@ class Resource(API, Operations):
             # Use the reference of the callback sent to get the callback data that was linked to the operation
             # This will returns a queryset, you will use .first() method or len() to manipultate it
             saved_ipn = IPN.objects.get(
-                client_id=ipn_data.get("client_id", ""), bank_id=ipn_data.get("bank_id", ""), account_number=ipn_data.get("bank", {}).get("account", ""))
+                client_id=ipn_data.get("client_id", ""), bank_id=ipn_data.get("bank_id", ""), account_number=ipn_data.get("account_number"))
 
             # if len(saved_ipn):
             #     # get the IPN
@@ -432,10 +433,10 @@ class Resource(API, Operations):
                         "code": f'{ipn_data.get("code", "-1")}',
                         "transaction_id": ipn_data.get("bank", {}).get("reference", "").strip(),
                         "date": ipn_data.get("transaction", {}).get('date', ""),
-                        "account_reference": f'{ipn_data.get("transaction", {}).get("reference", "").strip()}',
+                        "account_reference": f'{ipn_data.get("customer", {}).get("reference", "").strip()}',
                         "account_source": f"{ipn_data.get('bank',{}).get('account','')}",
                         "account_destination": ipn_data.get("transaction", {}).get("remarks", ""),
-                        "amount": ipn_data.get("transaction", {}).get('amount', -1),
+                        "amount": f"{ipn_data.get('transaction', {}).get('amount', -1)}",
                         "transaction_type": ipn_data.get('bank', {}).get('transactionType', '').lower(),
                     })
 
@@ -447,22 +448,43 @@ class Resource(API, Operations):
                     if int(response.get("code")) == 0:
                         response["completed"] = True
 
-                # This is a variable used to forward the standardized ipn data to another callback url
-                # If it was supplied and saved, else return the standardized response back to the
-                if forward:
-                    if ipn is not None:
-                        # we are setting additional data that needs to be sent back to the callback url
-                        # they are optional data
-                        if ipn.business_id is not None:
-                            self.callback_payload = {
-                                'businessid': str(ipn.business_id)
-                            }
-                        if ipn.tenant_id is not None:
-                            self.callback_headers = {
-                                '__tenant': str(ipn.tenant_id)
-                            }
-                        self._send_to_callback(
-                            response, callback_url=ipn.url, callback_headers=self.callback_headers, callback_payload=self.callback_payload, sleep=False)
+            elif ipn_data.get("bank_id", -1) == super().COOP:
+
+                response.update({
+                    "message": f'{ipn_data.get("Narration", "")}',
+                    "code": f'{ipn_data.get("code", "-1")}',
+                    "transaction_id": ipn_data.get("TransactionId", "").strip(),
+                    "date": datetime.strptime(ipn_data.get("TransactionDate", ""), '%Y-%m-%dT%H:%M:%S.%f%z').strftime("%Y:%m:%d %H:%M:%S"),
+                    "account_reference": f'{ipn_data.get("MessageReference", "").strip()}',
+                    "account_source": f"{ipn_data.get('AccountNumber','')}",
+                    "account_destination": f'{ipn_data.get("CustMemo", {}).get("CustMemoLine3", "")} {ipn_data.get("CustMemo", {}).get("CustMemoLine2", "")}',
+                    "amount": f'{ipn_data.get("Amount", "-1")}',
+                    "transaction_type": ipn_data.get('EventType', '').lower(),
+                })
+
+                if ipn_data.get("EventType", '').lower() == 'credit':
+                    response["account_source"] = f'{ipn_data.get("CustMemo", {}).get("CustMemoLine3", "")} {ipn_data.get("CustMemo", {}).get("CustMemoLine2", "")}'
+                    response["account_destination"] = f"{ipn_data.get('AccountNumber','')}"
+
+                if int(response.get("code")) == 0:
+                    response["completed"] = True
+
+            # This is a variable used to forward the standardized ipn data to another callback url
+            # If it was supplied and saved, else return the standardized response back to the
+            if forward:
+                if ipn is not None:
+                    # we are setting additional data that needs to be sent back to the callback url
+                    # they are optional data
+                    if ipn.business_id is not None:
+                        self.callback_payload = {
+                            'businessid': str(ipn.business_id)
+                        }
+                    if ipn.tenant_id is not None:
+                        self.callback_headers = {
+                            '__tenant': str(ipn.tenant_id)
+                        }
+                    self._send_to_callback(
+                        response, callback_url=ipn.url, callback_headers=self.callback_headers, callback_payload=self.callback_payload, sleep=False)
 
         except ObjectDoesNotExist:
             print("Either the IPN or entry doesn't exist.")
